"use strict";

const argx = require('argx'),
    SrchLogger = require('./logging/srch_logger'),
    async = require('async');

const types = require('./types.json'),
    matchAnyProp = require('./matching/match_any_prop'),
    searchType = require('./searching/search_type');

/** @lends apemanSrch */
function apemanSrch(terms, options, callback) {
    let args = argx(arguments);
    callback = args.pop('function') || argx.noop;
    options = args.pop('object') || {};
    terms = args.remain();

    let typeName = options.type;
    let logger = new SrchLogger({});
    async.waterfall([
        function (callback) {
            let invalid = typeName && !types[typeName];
            if (invalid) {
                callback(new Error('Unknown type: ' + typeName));
                return;
            }
            logger.logSearchStart();
            if (typeName) {
                searchType(types[typeName], callback);
            } else {
                async.concat(Object.keys(types), (typeName, callback) => {
                    searchType(types[typeName], callback);
                }, callback);
            }
        },
        function (found, callback) {
            logger.logSearchDone();
            found = [].concat(found || []).filter((found) => {
                if (terms.length == 0) {
                    found.hit = true;
                    return found;
                }
                for (let i = 0, len = terms.length; i < len; i++) {
                    let term = terms[i];
                    let hit = matchAnyProp(found, term);
                    if (hit) {
                        found.hit = true;
                        found.hitTerm = term;
                        return found;
                    }
                }
                found.hit = false;
                return found;
            });
            logger.logSearched(found, terms);
            callback(null);
        }
    ], callback);
}


module.exports = apemanSrch;
