/**
 * List repository for an orgnization.
 * @function listOrgRepo
 * @param {string} name - Name of orgnization.
 * @param {function} callback - Callback when done.
 */

"use strict";

const _apiRequest = require('./_api_request');

/** @lends listOrgRepo */
function listOrgRepo(name, callback) {
    let pathname = `/orgs/${name}/repos`;
    _apiRequest(pathname, (err, res, body) => {
        if (err) {
            callback(err);
        } else {
            let success = res.statusCode == 200;
            if (success) {
                let data = JSON.parse(body).map(function (data) {
                    return {
                        name: data.name,
                        full_name: data.full_name,
                        private: data.private,
                        description: data.description,
                        url: data.url,
                        fork: data.fork
                    };
                });
                callback(null, data);
            } else {
                callback(new Error('Request failed with status: ' + res.statusCode));
            }
        }
    });
}

module.exports = listOrgRepo;
